@@ -35,8 +35,8 @@ class BaseChart():
         'birth_label_wrapping_active': True,
         'birth_label_letter_x_offset': 0,
         'birth_label_letter_y_offset': 1,
-        'fade_individual_color': True,
-        'fade_individual_color_black_age': 200,
+        'fade_individual_color': False,
+        'fade_individual_color_age': 150,
         'marriage_label_active': False,
         'no_ring': False,
         'death_label_active': True,
@@ -72,7 +72,7 @@ class BaseChart():
         'dark': {
             'descendant_chart_marriage_lines': (200, 200, 200),
             'fade_to_death': (255, 255, 255),
-            'grid_line': (20, 20, 20),
+            'grid_line': (120, 120, 120),
             'text_label': (200, 200, 200)
         }
     }
