@@ -17,6 +17,18 @@ class BaseFamily():
     def __repr__(self):
         return 'family "' + self.husb_name + '"+"' + self.wife_name + '"'
 
+    def __lt__(self, other):
+        """
+        Sorting by marriage date
+
+        Args:
+            other (BaseFamily): the other instance
+
+        Returns:
+            bool: is less than
+        """
+        return self.marriage['ordinal_value'] < other.marriage['ordinal_value']
+
     def _initialize(self):
         self.husband_individual_id, self.wife_individual_id = self._get_husband_and_wife_id()
         self.children_individual_ids = self._get_children_ids()
@@ -30,6 +42,16 @@ class BaseFamily():
         """
         return len(self.graphical_representations) > 0
 
+    def has_graphical_representation_of_spouse(self):
+        """
+        true if at least one spouse has a graphical representation
+
+        Returns:
+            bool: has graphical representation of spouse
+        """
+        return (self.husb is not None and self.husb.has_graphical_representation()) or \
+                    (self.wife is not None and self.wife.has_graphical_representation())
+
     def has_children(self):
         """
         this family has children
@@ -110,25 +132,25 @@ class BaseFamily():
             raise NotImplementedError()
         return []
 
-    def _get_husb_name(self):
+    @property
+    def husb_name(self):
         if True:
             raise NotImplementedError()
         return ""
 
-    husb_name = property(_get_husb_name)
-
-    def _get_wife_name(self):
+    @property
+    def wife_name(self):
         if True:
             raise NotImplementedError()
-    wife_name = property(_get_wife_name)
+        return ""
 
-    def _get_husb(self):
+    @property
+    def husb(self):
         return self._instances[('i', self.husband_individual_id)]
-    husb = property(_get_husb)
 
-    def _get_wife(self):
+    @property
+    def wife(self):
         return self._instances[('i', self.wife_individual_id)]
-    wife = property(_get_wife)
 
     @property
     def marriage_date(self):
@@ -136,7 +158,6 @@ class BaseFamily():
 
     @property
     def marriage_label(self):
-        # label = self.marriage['date'].date().strftime('%d.%m.%Y')
         event = self.marriage
         date_str = self.marriage_date
         if event['comment']:
